==> eiffelstudio-18.01.10.1424.tar: F_code/C10/co459.c <==
/*
 * Code for class CONF_ERROR_UUID_MISMATCH_IN_REDIRECTION
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "co459.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {CONF_ERROR_UUID_MISMATCH_IN_REDIRECTION}.make */
void F744_7528 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3, EIF_REFERENCE arg4)
{
	GTCX
	RTLD;
	
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,arg2);
	RTLR(3,arg3);
	RTLR(4,arg4);
	RTLIU(5);
	
	RTGC;
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg1;
	RTAR(Current, arg2);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg2;
	RTAR(Current, arg3);
	*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) arg3;
	RTAR(Current, arg4);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) arg4;
	RTLE;
}

/* {CONF_ERROR_UUID_MISMATCH_IN_REDIRECTION}.file */
EIF_REFERENCE F744_7529 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {CONF_ERROR_UUID_MISMATCH_IN_REDIRECTION}.redirected_file */
EIF_REFERENCE F744_7530 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


/* {CONF_ERROR_UUID_MISMATCH_IN_REDIRECTION}.text */
EIF_REFERENCE F744_7531 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_CHARACTER_32 tw1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(8);
	RTLR(0,Result);
	RTLR(1,loc1);
	RTLR(2,Current);
	RTLR(3,tr1);
	RTLR(4,tr2);
	RTLR(5,loc2);
	RTLR(6,loc3);
	RTLR(7,loc4);
	RTLIU(8);
	
	RTGC;
	Result = RTMS32_EX_H("U\000\000\000U\000\000\000I\000\000\000D\000\000\000 \000\000\000m\000\000\000i\000\000\000s\000\000\000m\000\000\000a\000\000\000t\000\000\000c\000\000\000h\000\000\000e\000\000\000d\000\000\000 \000\000\000i\000\000\000n\000\000\000 \000\000\000c\000\000\000o\000\000\000n\000\000\000f\000\000\000i\000\000\000g\000\000\000u\000\000\000r\000\000\000a\000\000\000t\000\000\000i\000\000\000o\000\000\000n\000\000\000 \000\000\000f\000\000\000i\000\000\000l\000\000\000e\000\000\000 \000\000\000r\000\000\000e\000\000\000d\000\000\000i\000\000\000r\000\000\000e\000\000\000c\000\000\000t\000\000\000i\000\000\000o\000\000\000n\000\000\000:\000\000\000\012\000\000\000",51,1702609674);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	loc1 = tr1;
	if (EIF_TEST(loc1)) {
		tr1 = RTMS32_EX_H(" \000\000\000-\000\000\000 \000\000\000\"\000\000\000",4,539828258);
		tr1 = F1114_9675(tr1, loc1);
		tr2 = RTMS_EX_H("\"",1,34);
		tr1 = F1114_9675(RTCW(tr1), tr2);
		F1114_9673(RTCW(Result), tr1);
		tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '\012';
		F1114_9687(RTCW(Result), tw1);
	}
	tr1 = RTMS_EX_H("   uuid=",8,967316029);
	tr1 = F1107_9418(tr1);
	F1114_9673(RTCW(Result), tr1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	loc2 = tr1;
	if (EIF_TEST(loc2)) {
		tr1 = F1130_10087(loc2);
		tr1 = F1107_9418(RTCW(tr1));
		F1114_9673(RTCW(Result), tr1);
	} else {
		tr1 = RTMS_EX_H("none",4,1852796517);
		tr1 = F1107_9418(tr1);
		F1114_9673(RTCW(Result), tr1);
	}
	tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '\012';
	F1114_9687(RTCW(Result), tw1);
	tr1 = *(EIF_REFERENCE *)(Current);
	loc3 = tr1;
	if (EIF_TEST(loc3)) {
		tr1 = RTMS32_EX_H(" \000\000\000-\000\000\000 \000\000\000\"\000\000\000",4,539828258);
		tr1 = F1114_9675(tr1, loc3);
		tr2 = RTMS_EX_H("\"",1,34);
		tr1 = F1114_9675(RTCW(tr1), tr2);
		F1114_9673(RTCW(Result), tr1);
		tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '\012';
		F1114_9687(RTCW(Result), tw1);
	}
	tr1 = RTMS_EX_H("   uuid=",8,967316029);
	tr1 = F1107_9418(tr1);
	F1114_9673(RTCW(Result), tr1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	loc4 = tr1;
	if (EIF_TEST(loc4)) {
		tr1 = F1130_10087(loc4);
		tr1 = F1107_9418(RTCW(tr1));
		F1114_9673(RTCW(Result), tr1);
	} else {
		tr1 = RTMS_EX_H("none",4,1852796517);
		tr1 = F1107_9418(tr1);
		F1114_9673(RTCW(Result), tr1);
	}
	RTLE;
	return Result;
}

/* {CONF_ERROR_UUID_MISMATCH_IN_REDIRECTION}.file_uuid */
EIF_REFERENCE F744_7532 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_2_);
}


/* {CONF_ERROR_UUID_MISMATCH_IN_REDIRECTION}.redirected_file_uuid */
EIF_REFERENCE F744_7533 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_3_);
}


void EIF_Minit459 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.11.10.2592.tar: F_code/C10/co459.c <==
/*
 * Code for class CONF_ERROR_UUID_MISMATCH_IN_REDIRECTION
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "co459.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {CONF_ERROR_UUID_MISMATCH_IN_REDIRECTION}.make */
void F545_6953 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3, EIF_REFERENCE arg4)
{
	GTCX
	RTLD;
	
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,arg2);
	RTLR(3,arg3);
	RTLR(4,arg4);
	RTLIU(5);
	
	RTGC;
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg1;
	RTAR(Current, arg2);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg2;
	RTAR(Current, arg3);
	*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) arg3;
	RTAR(Current, arg4);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) arg4;
	RTLE;
}

/* {CONF_ERROR_UUID_MISMATCH_IN_REDIRECTION}.file */
EIF_REFERENCE F545_6954 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {CONF_ERROR_UUID_MISMATCH_IN_REDIRECTION}.redirected_file */
EIF_REFERENCE F545_6955 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


/* {CONF_ERROR_UUID_MISMATCH_IN_REDIRECTION}.text */
EIF_REFERENCE F545_6956 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_CHARACTER_32 tw1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(8);
	RTLR(0,Result);
	RTLR(1,loc1);
	RTLR(2,Current);
	RTLR(3,tr1);
	RTLR(4,tr2);
	RTLR(5,loc2);
	RTLR(6,loc3);
	RTLR(7,loc4);
	RTLIU(8);
	
	RTGC;
	Result = RTMS32_EX_H("U\000\000\000U\000\000\000I\000\000\000D\000\000\000 \000\000\000m\000\000\000i\000\000\000s\000\000\000m\000\000\000a\000\000\000t\000\000\000c\000\000\000h\000\000\000e\000\000\000d\000\000\000 \000\000\000i\000\000\000n\000\000\000 \000\000\000c\000\000\000o\000\000\000n\000\000\000f\000\000\000i\000\000\000g\000\000\000u\000\000\000r\000\000\000a\000\000\000t\000\000\000i\000\000\000o\000\000\000n\000\000\000 \000\000\000f\000\000\000i\000\000\000l\000\000\000e\000\000\000 \000\000\000r\000\000\000e\000\000\000d\000\000\000i\000\000\000r\000\000\000e\000\000\000c\000\000\000t\000\000\000i\000\000\000o\000\000\000n\000\000\000:\000\000\000\012\000\000\000",51,1702609674);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	loc1 = tr1;
	if (EIF_TEST(loc1)) {
		tr1 = RTMS32_EX_H(" \000\000\000-\000\000\000 \000\000\000\"\000\000\000",4,539828258);
		tr1 = F1129_9834(tr1, loc1);
		tr2 = RTMS32_EX_H("\"\000\000\000",1,34);
		tr1 = F1129_9834(RTCW(tr1), tr2);
		F1129_9832(RTCW(Result), tr1);
		tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '\012';
		F1129_9846(RTCW(Result), tw1);
	}
	tr1 = RTMS32_EX_H(" \000\000\000 \000\000\000 \000\000\000u\000\000\000u\000\000\000i\000\000\000d\000\000\000=\000\000\000",8,967316029);
	F1129_9832(RTCW(Result), tr1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	loc2 = tr1;
	if (EIF_TEST(loc2)) {
		tr1 = F1146_10308(loc2);
		F1129_9832(RTCW(Result), tr1);
	} else {
		tr1 = RTMS32_EX_H("n\000\000\000o\000\000\000n\000\000\000e\000\000\000",4,1852796517);
		F1129_9832(RTCW(Result), tr1);
	}
	tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '\012';
	F1129_9846(RTCW(Result), tw1);
	tr1 = *(EIF_REFERENCE *)(Current);
	loc3 = tr1;
	if (EIF_TEST(loc3)) {
		tr1 = RTMS32_EX_H(" \000\000\000-\000\000\000 \000\000\000\"\000\000\000",4,539828258);
		tr1 = F1129_9834(tr1, loc3);
		tr2 = RTMS32_EX_H("\"\000\000\000",1,34);
		tr1 = F1129_9834(RTCW(tr1), tr2);
		F1129_9832(RTCW(Result), tr1);
		tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '\012';
		F1129_9846(RTCW(Result), tw1);
	}
	tr1 = RTMS32_EX_H(" \000\000\000 \000\000\000 \000\000\000u\000\000\000u\000\000\000i\000\000\000d\000\000\000=\000\000\000",8,967316029);
	F1129_9832(RTCW(Result), tr1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	loc4 = tr1;
	if (EIF_TEST(loc4)) {
		tr1 = F1146_10308(loc4);
		F1129_9832(RTCW(Result), tr1);
	} else {
		tr1 = RTMS32_EX_H("n\000\000\000o\000\000\000n\000\000\000e\000\000\000",4,1852796517);
		F1129_9832(RTCW(Result), tr1);
	}
	RTLE;
	return Result;
}

/* {CONF_ERROR_UUID_MISMATCH_IN_REDIRECTION}.file_uuid */
EIF_REFERENCE F545_6957 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_2_);
}


/* {CONF_ERROR_UUID_MISMATCH_IN_REDIRECTION}.redirected_file_uuid */
EIF_REFERENCE F545_6958 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_3_);
}


void EIF_Minit459 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
